@@ -215,6 +215,10 @@ class BaseArboristClient(AuthzClient):
     def delete(self, url, **kwargs):
         return self.request("delete", url, **kwargs)
 
+    @maybe_sync
+    async def get_users(self, params=None, **kwargs):
+        return await self.get(url=self._user_url, params=params, **kwargs)
+
     @maybe_sync
     async def healthy(self, timeout=1):
         """
@@ -538,6 +542,9 @@ class BaseArboristClient(AuthzClient):
 
     @maybe_sync
     async def create_policy(self, policy_json, skip_if_exists=True):
+        return await self._create_policy(policy_json, skip_if_exists)
+
+    async def _create_policy(self, policy_json, skip_if_exists=True):
         response = await self.post(self._policy_url, json=policy_json)
         if response.code == 409 and skip_if_exists:
             # already exists; this is ok, but leave warning
@@ -601,7 +608,7 @@ class BaseArboristClient(AuthzClient):
         if response.code == 404 and create_if_not_exist:
             self.logger.info("Policy `{}` does not exist: Creating".format(policy_id))
             policy_json["id"] = policy_id
-            return await self.create_policy(policy_json, skip_if_exists=False)
+            return await self._create_policy(policy_json, skip_if_exists=False)
         if not response.successful:
             msg = "could not put policy `{}` in arborist: {}".format(
                 policy_id, response.error_msg
